#[repr(i32)]pub enum VibeConnectionStatus {
Idle = 0,
Connecting = 1,
Connected = 2,
Disconnecting = 3,
Disconnected = 4,
}Expand description
Connection state reported by the SDK runtime. Connection lifecycle state used by status integrations.
Variants
Idle = 0
No connection attempt is active.
Connecting = 1
A connection attempt is in progress.
Connected = 2
The connection is established.
Disconnecting = 3
Disconnect is in progress.
Disconnected = 4
The connection has been closed.
Implementations
Sourceimpl VibeConnectionStatus
impl VibeConnectionStatus
Sourcepub fn trans(
&mut self,
new_status: VibeConnectionStatus,
) -> Result<VibeConnectionStatus, VibeEngineError>
pub fn trans( &mut self, new_status: VibeConnectionStatus, ) -> Result<VibeConnectionStatus, VibeEngineError>
Applies a validated transition to new_status.
Returns
Ok(new_status) when the transition is allowed, or VibeEngineError
when the transition is invalid for the current state.
Examples
use vibe_ready::{VibeConnectionStatus, VibeResult};
let mut status = VibeConnectionStatus::Idle;
assert_eq!(status.trans(VibeConnectionStatus::Connecting)?, VibeConnectionStatus::Connecting);Trait Implementations
Sourceimpl Clone for VibeConnectionStatus
impl Clone for VibeConnectionStatus
Sourcefn clone(&self) -> VibeConnectionStatus
fn clone(&self) -> VibeConnectionStatus
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for VibeConnectionStatus
Sourceimpl Debug for VibeConnectionStatus
impl Debug for VibeConnectionStatus
Sourceimpl Default for VibeConnectionStatus
impl Default for VibeConnectionStatus
Sourcefn default() -> VibeConnectionStatus
fn default() -> VibeConnectionStatus
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for VibeConnectionStatus
impl<'de> Deserialize<'de> for VibeConnectionStatus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for VibeConnectionStatus
impl Display for VibeConnectionStatus
impl Eq for VibeConnectionStatus
Sourceimpl PartialEq for VibeConnectionStatus
impl PartialEq for VibeConnectionStatus
Sourcefn eq(&self, other: &VibeConnectionStatus) -> bool
fn eq(&self, other: &VibeConnectionStatus) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for VibeConnectionStatus
impl Serialize for VibeConnectionStatus
impl StructuralPartialEq for VibeConnectionStatus