#[repr(u8)]pub enum VibeEngineState {
Created = 0,
Running = 1,
Closing = 2,
Closed = 3,
}Expand description
Lifecycle state of a VibeEngine.
Lifecycle state of a VibeEngine.
Variants
Created = 0
The engine value has been constructed but is not accepting work yet.
Running = 1
The engine is ready to accept tasks and storage operations.
Closing = 2
The engine is shutting down resources and no longer accepts new work.
Closed = 3
The engine has released its runtime-owned resources.