VibeErrorCode

Enum VibeErrorCode 

#[repr(i32)]
pub enum VibeErrorCode {
Show 45 variants Unknown = -1, Success = 200, EngineDropped = 100_001, DatabaseNotOpened = 100_002, DatabaseOpenFailed = 100_003, LogDatabaseOpenFailed = 100_223, WorkDatabaseOpenFailed = 132_003, DatabaseIOError = 100_004, DatabaseTargetNotFound = 100_005, DatabaseThreadError = 100_006, PostError = 100_007, Cancelled = 100_008, ParameterEmpty = 100_012, OAuthError = 100_013, ConfigError = 100_014, IOError = 100_017, BadRequest = 100_018, RequestError = 100_019, InternalServerError = 100_020, NetworkError = 100_021, UnsupportedError = 100_022, TimeoutError = 100_023, ConnectError = 100_024, TlsConnectError = 100_025, OptionsParseError = 100_026, SerdeDeserializeError = 100_027, SerdeSerializeError = 100_028, InvalidArgumentLogInfo = 100_029, MPSCSendError = 100_037, GenerateQRError = 10_005, RuntimeError = 10_006, BeaverError = 10_007, SocketRecvTimeout = 10_008, SocketClosed = 10_009, ProtocParseError = 10_010, SocketNotOpened = 10_011, TaskInterruptionError = 10_012, ConnectionClosed = 30_001, ConnectionExists = 34_001, ConnectionClosing = 30_027, InternalError = 32_002, NotLoggedInError = 32_003, PageTokenError = 32_004, ClipboardInitializeError = 32_005, NotSupportedYet = 999_999,
}
Stable error code used by VibeError. Stable numeric error codes returned by vibe-ready.

Variants



Unknown = -1

Unknown or unmapped error.



Success = 200

Operation completed successfully.



EngineDropped = 100_001

Engine has already been dropped.



DatabaseNotOpened = 100_002

Database has not been opened yet.



DatabaseOpenFailed = 100_003

Database open operation failed.



LogDatabaseOpenFailed = 100_223

Log database open operation failed.



WorkDatabaseOpenFailed = 132_003

Work database open operation failed.



DatabaseIOError = 100_004

Database I/O operation failed.



DatabaseTargetNotFound = 100_005

Requested database target was not found.



DatabaseThreadError = 100_006

Database worker thread failed.



PostError = 100_007

Task could not be posted to the runtime.



Cancelled = 100_008

Task was cancelled before it could complete (B9 scheduler).



ParameterEmpty = 100_012

Required parameter is empty.



OAuthError = 100_013

OAuth flow failed.



ConfigError = 100_014

Engine configuration is invalid.



IOError = 100_017

Standard I/O error.



BadRequest = 100_018

HTTP or protocol bad-request error.



RequestError = 100_019

Request operation failed.



InternalServerError = 100_020

Remote service returned an internal server error.



NetworkError = 100_021

Network operation failed.



UnsupportedError = 100_022

Requested operation is unsupported.



TimeoutError = 100_023

Operation timed out.



ConnectError = 100_024

Connection attempt failed.



TlsConnectError = 100_025

TLS connection attempt failed.



OptionsParseError = 100_026

Options parsing failed.



SerdeDeserializeError = 100_027

Deserialization failed.



SerdeSerializeError = 100_028

Serialization failed.



InvalidArgumentLogInfo = 100_029

Log information argument is invalid.



MPSCSendError = 100_037

MPSC channel send failed.



GenerateQRError = 10_005

QR generation failed.



RuntimeError = 10_006

Runtime operation failed.



BeaverError = 10_007

Internal beaver subsystem failed.



SocketRecvTimeout = 10_008

Socket receive operation timed out.



SocketClosed = 10_009

Socket has been closed.



ProtocParseError = 10_010

Protocol parsing failed.



SocketNotOpened = 10_011

Socket has not been opened.



TaskInterruptionError = 10_012

Task was interrupted.



ConnectionClosed = 30_001

Connection is closed.



ConnectionExists = 34_001

Connection already exists.



ConnectionClosing = 30_027

Connection is currently closing.



InternalError = 32_002

Internal operation failed.



NotLoggedInError = 32_003

User is not logged in.



PageTokenError = 32_004

Page token is invalid.



ClipboardInitializeError = 32_005

Clipboard initialization failed.



NotSupportedYet = 999_999

Feature or backend support has not been implemented yet.

Implementations

Source

impl VibeEngineErrorCode

pub fn code(&self) -> i32

Returns the stable numeric code associated with this variant.

Returns

The i32 code used in serialized errors and logs.

Examples
use vibe_ready::VibeErrorCode;

assert_eq!(VibeErrorCode::Success.code(), 200);