VibeCallbackExecutor

Struct VibeCallbackExecutor 

pub struct VibeCallbackExecutor { /* private fields */ }
Callback executor returned by VibeEngineExecutor::callback. Executes user callbacks on the engine callback thread pool.

Use this when an integration receives events on an async/runtime thread but wants user callbacks to run on the configured callback pool.

Examples

use vibe_ready::{VibeEngine, VibeEngineConfig, VibeResult};

let engine = VibeEngine::create(VibeEngineConfig::builder().build())?;
let callbacks = engine.executor().callback();
callbacks.execute(|| println!("callback ran"));

Implementations

Source

impl VibeCallbackExecutor

pub fn execute<F>(&self, cb: F)
where F: FnOnce() + Send + 'static,

Executes a zero-argument callback on the callback pool.

Returns

This method returns () after queuing the callback.

pub fn once<F, R>(&self, cb: F) -> impl FnOnce(R) + Send + 'static
where F: FnOnce(R) + Send + 'static, R: Send + 'static,

Converts a one-shot single-argument callback into a pool-dispatched callback.

Returns

A FnOnce(R) wrapper that moves the argument into the callback pool.

pub fn once2<F, R1, R2>(&self, cb: F) -> impl FnOnce(R1, R2) + Send + 'static
where F: FnOnce(R1, R2) + Send + 'static, R1: Send + 'static, R2: Send + 'static,

Converts a one-shot two-argument callback into a pool-dispatched callback.

Returns

A FnOnce(R1, R2) wrapper that moves both arguments into the callback pool.

pub fn once3<F, R1, R2, R3>( &self, cb: F, ) -> impl FnOnce(R1, R2, R3) + Send + 'static
where F: FnOnce(R1, R2, R3) + Send + 'static, R1: Send + 'static, R2: Send + 'static, R3: Send + 'static,

Converts a one-shot three-argument callback into a pool-dispatched callback.

Returns

A FnOnce(R1, R2, R3) wrapper that moves all arguments into the callback pool.

pub fn once3_boxed<F, R1, R2, R3>( &self, cb: F, ) -> Box<dyn FnOnce(R1, R2, R3) + Send + Sync + 'static>
where F: FnOnce(R1, R2, R3) + Send + Sync + 'static, R1: Send + 'static, R2: Send + 'static, R3: Send + 'static,

Returns a boxed one-shot three-argument callback wrapper.

Returns

A boxed FnOnce that dispatches the original callback on the pool.

pub fn boxed_fn0<F>(&self, cb: F) -> Box<dyn Fn() + Send + Sync + 'static>
where F: Fn() + Send + Sync + 'static,

Returns a boxed zero-argument callback wrapper.

Returns

A boxed Fn that can be cloned or stored by APIs expecting trait objects.

pub fn boxed_fn<F, R>(&self, cb: F) -> Box<dyn Fn(R) + Send + Sync + 'static>
where F: Fn(R) + Send + Sync + 'static, R: Send + 'static,

Returns a boxed one-argument callback wrapper.

Returns

A boxed Fn(R) that dispatches each invocation on the callback pool.

pub fn boxed_fn2<F, R1, R2>( &self, cb: F, ) -> Box<dyn Fn(R1, R2) + Send + Sync + 'static>
where F: Fn(R1, R2) + Send + Sync + 'static, R1: Send + 'static, R2: Send + 'static,

Returns a boxed two-argument callback wrapper.

Returns

A boxed Fn(R1, R2) that dispatches each invocation on the callback pool.

pub fn fn2<F, R1, R2>(&self, cb: F) -> impl Fn(R1, R2) + Send + Sync + 'static
where F: Fn(R1, R2) + Send + Sync + 'static, R1: Send + 'static, R2: Send + 'static,

Returns an unboxed two-argument callback wrapper.

Returns

An impl Fn(R1, R2) wrapper that dispatches each invocation on the pool.

pub fn fn2_cloneable<F, R1, R2>( &self, cb: F, ) -> impl Fn(R1, R2) + Clone + Send + Sync + 'static
where F: Fn(R1, R2) + Clone + Send + Sync + 'static, R1: Send + 'static, R2: Send + 'static,

Returns a cloneable unboxed two-argument callback wrapper.

Returns

A cloneable impl Fn(R1, R2) wrapper for APIs that duplicate callbacks.

pub fn boxed_fn3<F, R1, R2, R3>( &self, cb: F, ) -> Box<dyn Fn(R1, R2, R3) + Send + Sync + 'static>
where F: Fn(R1, R2, R3) + Send + Sync + 'static, R1: Send + 'static, R2: Send + 'static, R3: Send + 'static,

Returns a boxed three-argument callback wrapper.

Returns

A boxed Fn(R1, R2, R3) that dispatches each invocation on the pool.

pub fn boxed_fn4<F, R1, R2, R3, R4>( &self, cb: F, ) -> Box<dyn Fn(R1, R2, R3, R4) + Send + Sync + 'static>
where F: Fn(R1, R2, R3, R4) + Send + Sync + 'static, R1: Send + 'static, R2: Send + 'static, R3: Send + 'static, R4: Send + 'static,

Returns a boxed four-argument callback wrapper.

Returns

A boxed Fn(R1, R2, R3, R4) dispatched on the callback pool.

pub fn boxed_fn5<F, R1, R2, R3, R4, R5>( &self, cb: F, ) -> Box<dyn Fn(R1, R2, R3, R4, R5) + Send + Sync + 'static>
where F: Fn(R1, R2, R3, R4, R5) + Send + Sync + 'static, R1: Send + 'static, R2: Send + 'static, R3: Send + 'static, R4: Send + 'static, R5: Send + 'static,

Returns a boxed five-argument callback wrapper.

Returns

A boxed Fn(R1, R2, R3, R4, R5) dispatched on the callback pool.

pub fn boxed_ref_fn2<F, R1, R2>( &self, cb: F, ) -> Box<dyn Fn(&R1, R2) + Send + Sync + 'static>
where F: Fn(&R1, R2) + Send + Sync + 'static, R1: Clone + Send + 'static, R2: Send + 'static,

Returns a boxed callback wrapper that accepts a borrowed first argument.

Returns

A boxed Fn(&R1, R2) wrapper. The borrowed value is cloned before the callback is moved to the pool.

pub fn boxed_str_fn<F>( &self, cb: F, ) -> Box<dyn Fn(&str) + Send + Sync + 'static>
where F: Fn(&str) + Send + Sync + 'static,

Returns a boxed string-slice callback wrapper.

Returns

A boxed Fn(&str) wrapper that owns the string before dispatching.

pub fn boxed_str_fn2<F, R2>( &self, cb: F, ) -> Box<dyn Fn(&str, R2) + Send + Sync + 'static>
where F: Fn(&str, R2) + Send + Sync + 'static, R2: Send + 'static,

Returns a boxed &str plus one-argument callback wrapper.

Returns

A boxed Fn(&str, R2) wrapper that owns the string before dispatching.

pub fn boxed_str_fn3<F, R2, R3>( &self, cb: F, ) -> Box<dyn Fn(&str, R2, R3) + Send + Sync + 'static>
where F: Fn(&str, R2, R3) + Send + Sync + 'static, R2: Send + 'static, R3: Send + 'static,

Returns a boxed &str plus two-argument callback wrapper.

Returns

A boxed Fn(&str, R2, R3) wrapper that owns the string before dispatching.

pub fn boxed_str_fn4<F, R2, R3, R4>( &self, cb: F, ) -> Box<dyn Fn(&str, R2, R3, R4) + Send + Sync + 'static>
where F: Fn(&str, R2, R3, R4) + Send + Sync + 'static, R2: Send + 'static, R3: Send + 'static, R4: Send + 'static,

Returns a boxed &str plus three-argument callback wrapper.

Returns

A boxed Fn(&str, R2, R3, R4) wrapper that owns the string before dispatching.

pub fn boxed_str_str4_fn<F, R2, R3>( &self, cb: F, ) -> Box<dyn Fn(&str, R2, R3, &str) + Send + Sync + 'static>
where F: Fn(&str, R2, R3, &str) + Send + Sync + 'static, R2: Send + 'static, R3: Send + 'static,

Returns a boxed callback wrapper with first and fourth string arguments.

Returns

A boxed Fn(&str, R2, R3, &str) wrapper that owns both string slices before dispatching.