VibeEngineConfigBuilder

Struct VibeEngineConfigBuilder 

pub struct VibeEngineConfigBuilder { /* private fields */ }
Builder for VibeEngineConfig. Builder for VibeEngineConfig.

Implementations

Source

impl VibeEngineConfigBuilder

pub fn platform(self, platform: VibePlatformType) -> Self

Sets the host platform identifier.

Returns

The updated builder.

pub fn store_root_path(self, path: impl AsRef<Path>) -> Self

Sets the root directory used for SDK data.

Returns

The updated builder.

pub fn app_name(self, app_name: impl Into<String>) -> Self

Sets the application name.

Returns

The updated builder.

pub fn namespace(self, namespace: impl Into<String>) -> Self

Sets the namespace used to isolate data.

Returns

The updated builder.

pub fn app_config(self, app: VibeAppConfig) -> Self

Replaces the full application configuration.

Returns

The updated builder.

pub fn log_config(self, log: VibeLogConfig) -> Self

Replaces the full logging configuration.

Returns

The updated builder.

pub fn log_backend(self, backend: VibeLogBackend) -> Self

Sets the logging backend.

Returns

The updated builder.

pub fn log_level(self, level: LogLevel) -> Self

Sets the logging level.

Returns

The updated builder.

pub fn log_write_to_store(self, write_to_store: bool) -> Self

Enables or disables log persistence.

Returns

The updated builder.

pub fn log_output_stdout(self, output_stdout: bool) -> Self

Enables or disables stdout logging.

Returns

The updated builder.

pub fn log_retention_days(self, retention_days: u32) -> Self

Sets log retention in days for supported backends.

Returns

The updated builder.

pub fn log_max_rows(self, max_rows: usize) -> Self

Sets the maximum retained log rows for supported backends.

Returns

The updated builder.

pub fn store_config(self, store: VibeStoreConfig) -> Self

Replaces the full storage configuration.

Returns

The updated builder.

pub fn store_backend(self, backend: VibeStoreBackend) -> Self

Sets the key-value store backend.

Returns

The updated builder.

pub fn backup_strategy(self, backup_strategy: VibeBackupStrategy) -> Self

Sets the backup strategy for SDK-managed storage.

Returns

The updated builder.

pub fn runtime_config(self, runtime: VibeRuntimeConfig) -> Self

Replaces the full runtime configuration.

Returns

The updated builder.

pub fn runtime_worker_threads(self, worker_threads: usize) -> Self

Sets the Tokio worker-thread count for an engine-owned runtime.

Returns

The updated builder.

pub fn callback_threads(self, callback_threads: usize) -> Self

Sets the callback thread-pool size.

Returns

The updated builder.

pub fn queue_capacity( self, async_queue_capacity: usize, sync_queue_capacity: usize, ) -> Self

Sets async and sync queue capacities.

Returns

The updated builder.

pub fn priority_queue_capacity(self, capacity: usize) -> Self

Sets the per-lane priority queue capacity.

Returns

The updated builder.

pub fn encrypt(self, encrypt: bool) -> Self

Enables or disables storage encryption when supported by the backend.

Returns

The updated builder.

pub fn build(self) -> VibeEngineConfig

Finalizes the builder into a VibeEngineConfig.

Returns

The completed configuration. Call VibeEngineConfig::validate or crate::VibeEngine::create to validate it.