pub struct VibeEngineConfig {
pub platform_type: VibePlatformType,
pub store_root_path: PathBuf,
pub is_encrypt: bool,
pub app: VibeAppConfig,
pub log: VibeLogConfig,
pub store: VibeStoreConfig,
pub runtime: VibeRuntimeConfig,
}Expand description
Configuration used to create a VibeEngine.
Configuration used when creating a crate::VibeEngine.
Fields
platform_type: VibePlatformTypePlatform identifier used by integrations and logs.
store_root_path: PathBufRoot directory where vibe-ready stores app data.
is_encrypt: boolWhether persistent stores should use encryption when supported.
app: VibeAppConfigApplication identity used for namespacing local data.
log: VibeLogConfigLogging backend and retention configuration.
store: VibeStoreConfigWork-store backend and storage configuration.
runtime: VibeRuntimeConfigRuntime worker and queue configuration.
Implementations
Sourceimpl VibeEngineConfig
impl VibeEngineConfig
Sourcepub fn builder() -> VibeEngineConfigBuilder
pub fn builder() -> VibeEngineConfigBuilder
Starts building a VibeEngineConfig with production-ready defaults.
Returns
A VibeEngineConfigBuilder that can be customized before calling
VibeEngineConfigBuilder::build.
Examples
use vibe_ready::{VibeEngineConfig, VibePlatformType};
let config = VibeEngineConfig::builder()
.platform(VibePlatformType::MacOS)
.app_name("demo")
.namespace("examples")
.build();
assert_eq!(config.app_name(), "demo");Sourcepub fn store_path(&self) -> &PathBuf
pub fn store_path(&self) -> &PathBuf
Sourcepub fn is_encrypt(&self) -> bool
pub fn is_encrypt(&self) -> bool
Returns whether storage encryption was requested.
Returns
true when encryption is enabled in the store configuration.
Sourcepub fn platform(&self) -> VibePlatformType
pub fn platform(&self) -> VibePlatformType
Returns the configured platform identifier.
Returns
The VibePlatformType stored in this configuration.
Sourcepub fn log_config(&self) -> &VibeLogConfig
pub fn log_config(&self) -> &VibeLogConfig
Sourcepub fn store_config(&self) -> &VibeStoreConfig
pub fn store_config(&self) -> &VibeStoreConfig
Sourcepub fn runtime_config(&self) -> &VibeRuntimeConfig
pub fn runtime_config(&self) -> &VibeRuntimeConfig
Sourcepub fn app_store_path(&self) -> PathBuf
pub fn app_store_path(&self) -> PathBuf
Builds the app-specific storage directory path.
Returns
store_root_path / namespace / app_name as a PathBuf.
Examples
use std::path::PathBuf;
use vibe_ready::VibeEngineConfig;
let config = VibeEngineConfig::builder()
.store_root_path("/tmp/vibe-ready")
.namespace("dev")
.app_name("app")
.build();
assert_eq!(config.app_store_path(), PathBuf::from("/tmp/vibe-ready/dev/app"));Sourcepub fn validate(&self) -> Result<(), VibeEngineError>
pub fn validate(&self) -> Result<(), VibeEngineError>
Validates identifiers, backend availability, and runtime capacities.
Returns
Ok(()) when the configuration can be used to create an engine, or
VibeEngineError with configuration context when invalid.